<p align="center">
<img src="https://github.com/PKSHATechnology-Research/tdmelodic/raw/master/imgs/logo/logo_tdmelodic.svg" width="200" />
</p>


# Tokyo Dialect MELOdic accent DICtionary (tdmelodic) generator

[![document](https://readthedocs.org/projects/tdmelodic/badge/?version=latest)](https://tdmelodic.readthedocs.io/en/latest)
[![arXiv](https://img.shields.io/badge/arXiv-2009.09679-B31B1B.svg)](https://arxiv.org/abs/2009.09679)
[![Docker](https://github.com/PKSHATechnology-Research/tdmelodic/actions/workflows/docker-image.yml/badge.svg)](https://github.com/PKSHATechnology-Research/tdmelodic/actions/workflows/docker-image.yml)
[![Lilypond](https://github.com/PKSHATechnology-Research/tdmelodic/actions/workflows/img.yml/badge.svg)](https://github.com/PKSHATechnology-Research/tdmelodic/actions/workflows/img.yml)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)


This module generates a large scale accent dictionary of
Japanese (Tokyo dialect) using a neural network based technique.

For academic use, please cite the following paper.
[[IEEE Xplore]](https://ieeexplore.ieee.org/document/9054081)
[[arXiv]](https://arxiv.org/abs/2009.09679)

```bibtex
@inproceedings{tachibana2020icassp,
    author    = "H. Tachibana and Y. Katayama",
    title     = "Accent Estimation of {Japanese} Words from Their Surfaces and Romanizations
                 for Building Large Vocabulary Accent Dictionaries",
    booktitle = {2020 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP)},
    pages     = "8059--8063",
    year      = "2020",
    doi       = "10.1109/ICASSP40776.2020.9054081"
}
```

## Installation and Usage

- English: [tdmelodic Documentation](https://tdmelodic.readthedocs.io/en/latest)
- 日本語: [tdmelodic 利用マニュアル](https://tdmelodic.readthedocs.io/ja/latest)

## Acknowledgement
Some part of this work is based on the results obtained from a project subsidized by the New Energy and Industrial Technology Development Organization (NEDO).
